from probo.components.tag_classes.block_tags import (
    A,
    ABBR,
    ADDRESS,
    ARTICLE,
    ASIDE,
    AUDIO,
    B,
    BDI,
    BDO,
    BLOCKQUOTE,
    BODY,
    BUTTON,
    CANVAS,
    CAPTION,
    CITE,
    CODE,
    COLGROUP,
    DATA,
    DATALIST,
    DD,
    DEL,
    DETAILS,
    DFN,
    DIALOG,
    DIV,
    DL,
    DT,
    EM,
    FIELDSET,
    FIGCAPTION,
    FIGURE,
    FOOTER,
    FORM,
    H1,
    H2,
    H3,
    H4,
    H5,
    H6,
    HEAD,
    HEADER,
    HGROUP,
    HTML,
    I,
    IFRAME,
    INS,
    KBD,
    LABEL,
    LEGEND,
    LI,
    MAIN,
    MATH,
    MAP,
    MARK,
    MENU,
    METER,
    NAV,
    NOSCRIPT,
    OBJECT,
    OL,
    OPTGROUP,
    OPTION,
    OUTPUT,
    P,
    PORTAL,
    PICTURE,
    PRE,
    PROGRESS,
    Q,
    RP,
    RT,
    RUBY,
    S,
    SAMP,
    SCRIPT,
    SEARCH,
    SECTION,
    SELECT,
    SLOT,
    SMALL,
    SPAN,
    STRONG,
    STYLE,
    SUB,
    SUMMARY,
    SUP,
    TABLE,
    TBODY,
    TD,
    TEMPLATE,
    TEXTAREA,
    TFOOT,
    TH,
    THEAD,
    TIME,
    TITLE,
    TR,
    U,
    UL,
    VAR,
    VIDEO,
)

from probo.components.tag_classes.self_closing import (
    DOCTYPE,
    AREA,
    BASE,
    BR,
    COL,
    EMBED,
    HR,
    IMG,
    INPUT,
    LINK,
    META,
    PARAM,
    SOURCE,
    TRACK,
    WBR,
   
)
from probo.components.tag_classes.svg_tags import (
    G,
    DEFS,
    TEXT,
    TSPAN,
    SVG,
    SYMBOL,
    MARKER,
    PATTERN,
    MASK,
    CLIPPATH,
    LINEARGRADIENT,
    RADIALGRADIENT,
    FILTER,
    FECOMPONENTTRANSFER,
    FEDIFFUSELIGHTING,
    FEMERGE,
    FESPECULARLIGHTING,
    ANIMATEMOTION,
    FOREIGNOBJECT,
    PATH,
    CIRCLE,
    RECT,
    LINE,
    POLYLINE,
    POLYGON,
    ELLIPSE,
    IMAGE,
    FEBLEND,
    FECOLORMATRIX,
    FECOMPOSITE,
    FECONVOLVEMATRIX,
    FEDISPLACEMENTMAP,
    FEDROPSHADOW,
    FEFLOOD,
    FEFUNCA,
    FEFUNCB,
    FEFUNCG,
    FEFUNCR,
    FEGAUSSIANBLUR,
    FEIMAGE,
    FEMERGENODE,
    FEMORPHOLOGY,
    FEOFFSET,
    FEPOINTLIGHT,
    FESPOTLIGHT,
    FETILE,
    FETURBULENCE,
    ANIMATE,
    ANIMATETRANSFORM,
    SET,
    VIEW,
    USE,
    STOP,
)

__all__ = [
    # bock tags <x></x>
    "A",
    "ABBR",
    "ADDRESS",
    "ARTICLE",
    "ASIDE",
    "AUDIO",
    "B",
    "BDI",
    "BDO",
    "BLOCKQUOTE",
    "BODY",
    "BUTTON",
    "CANVAS",
    "CAPTION",
    "CITE",
    "CODE",
    "COLGROUP",
    "DATA",
    "DATALIST",
    "DD",
    "DEL",
    "DETAILS",
    "DFN",
    "DIALOG",
    "DIV",
    "DL",
    "DT",
    "EM",
    "FIELDSET",
    "FIGCAPTION",
    "FIGURE",
    "FOOTER",
    "FORM",
    "H1",
    "H2",
    "H3",
    "H4",
    "H5",
    "H6",
    "HEAD",
    "HEADER",
    "HGROUP",
    "HTML",
    "I",
    "IFRAME",
    "INS",
    "KBD",
    "LABEL",
    "LEGEND",
    "LI",
    "MAIN",
    "MATH",
    "MAP",
    "MARK",
    "MENU",
    "METER",
    "NAV",
    "NOSCRIPT",
    "OBJECT",
    "OL",
    "OPTGROUP",
    "OPTION",
    "OUTPUT",
    "P",
    "PORTAL",
    "PICTURE",
    "PRE",
    "PROGRESS",
    "Q",
    "RP",
    "RT",
    "RUBY",
    "S",
    "SAMP",
    "SCRIPT",
    "SEARCH",
    "SECTION",
    "SELECT",
    "SLOT",
    "SMALL",
    "SPAN",
    "STRONG",
    "STYLE",
    "SUB",
    "SUMMARY",
    "SUP",
    "TABLE",
    "TBODY",
    "TD",
    "TEMPLATE",
    "TEXTAREA",
    "TFOOT",
    "TH",
    "THEAD",
    "TIME",
    "TITLE",
    "TR",
    "U",
    "UL",
    "VAR",
    "VIDEO",
    # self closing <x />
    "DOCTYPE",
    "AREA",
    "BASE",
    "BR",
    "COL",
    "EMBED",
    "HR",
    "IMG",
    "INPUT",
    "LINK",
    "META",
    "PARAM",
    "SOURCE",
    "TRACK",
    "WBR",
    # svg elements
    'G',
    'DEFS',
    'TEXT',
    'TSPAN',
    'SVG',
    'SYMBOL',
    'MARKER',
    'PATTERN',
    'MASK',
    'CLIPPATH',
    'LINEARGRADIENT',
    'RADIALGRADIENT',
    'FILTER',
    'FECOMPONENTTRANSFER',
    'FEDIFFUSELIGHTING',
    'FEMERGE',
    'FESPECULARLIGHTING',
    'ANIMATEMOTION',
    'FOREIGNOBJECT',
    'PATH',
    'CIRCLE',
    'RECT',
    'LINE',
    'POLYLINE',
    'POLYGON',
    'ELLIPSE',
    'IMAGE',
    'FEBLEND',
    'FECOLORMATRIX',
    'FECOMPOSITE',
    'FECONVOLVEMATRIX',
    'FEDISPLACEMENTMAP',
    'FEDROPSHADOW',
    'FEFLOOD',
    'FEFUNCA',
    'FEFUNCB',
    'FEFUNCG',
    'FEFUNCR',
    'FEGAUSSIANBLUR',
    'FEIMAGE',
    'FEMERGENODE',
    'FEMORPHOLOGY',
    'FEOFFSET',
    'FEPOINTLIGHT',
    'FESPOTLIGHT',
    'FETILE',
    'FETURBULENCE',
    'ANIMATE',
    'ANIMATETRANSFORM',
    'SET',
    'VIEW',
    'USE',
    'STOP',
]
