from probo.components.tag_classes import (
    A,
    ABBR,
    ADDRESS,
    ARTICLE,
    ASIDE,
    AUDIO,
    B,
    BDI,
    BDO,
    BLOCKQUOTE,
    BODY,
    BUTTON,
    CANVAS,
    CAPTION,
    CITE,
    CODE,
    COLGROUP,
    DATA,
    DATALIST,
    DD,
    DEL,
    DETAILS,
    DFN,
    DIALOG,
    DIV,
    DL,
    DT,
    EM,
    FIELDSET,
    FIGCAPTION,
    FIGURE,
    FOOTER,
    FORM,
    H1,
    H2,
    H3,
    H4,
    H5,
    H6,
    HEAD,
    HEADER,
    HGROUP,
    HTML,
    I,
    IFRAME,
    INS,
    KBD,
    LABEL,
    LEGEND,
    LI,
    MAIN,
    MATH,
    MAP,
    MARK,
    MENU,
    METER,
    NAV,
    NOSCRIPT,
    OBJECT,
    OL,
    OPTGROUP,
    OPTION,
    OUTPUT,
    P,
    PORTAL,
    PICTURE,
    PRE,
    PROGRESS,
    Q,
    RP,
    RT,
    RUBY,
    S,
    SAMP,
    SCRIPT,
    SEARCH,
    SECTION,
    SELECT,
    SLOT,
    SMALL,
    SPAN,
    STRONG,
    STYLE,
    SUB,
    SUMMARY,
    SUP,
    TABLE,
    TBODY,
    TD,
    TEMPLATE,
    TEXTAREA,
    TFOOT,
    TH,
    THEAD,
    TIME,
    TITLE,
    TR,
    U,
    UL,
    VAR,
    VIDEO,
    # self closing <x />
    DOCTYPE,
    AREA,
    BASE,
    BR,
    COL,
    EMBED,
    HR,
    IMG,
    INPUT,
    LINK,
    META,
    PARAM,
    SOURCE,
    TRACK,
    WBR,
    # svg elements
    G,
    DEFS,
    TEXT,
    TSPAN,
    SVG,
    SYMBOL,
    MARKER,
    PATTERN,
    MASK,
    CLIPPATH,
    LINEARGRADIENT,
    RADIALGRADIENT,
    FILTER,
    FECOMPONENTTRANSFER,
    FEDIFFUSELIGHTING,
    FEMERGE,
    FESPECULARLIGHTING,
    ANIMATEMOTION,
    FOREIGNOBJECT,
    PATH,
    CIRCLE,
    RECT,
    LINE,
    POLYLINE,
    POLYGON,
    ELLIPSE,
    IMAGE,
    FEBLEND,
    FECOLORMATRIX,
    FECOMPOSITE,
    FECONVOLVEMATRIX,
    FEDISPLACEMENTMAP,
    FEDROPSHADOW,
    FEFLOOD,
    FEFUNCA,
    FEFUNCB,
    FEFUNCG,
    FEFUNCR,
    FEGAUSSIANBLUR,
    FEIMAGE,
    FEMERGENODE,
    FEMORPHOLOGY,
    FEOFFSET,
    FEPOINTLIGHT,
    FESPOTLIGHT,
    FETILE,
    FETURBULENCE,
    ANIMATE,
    ANIMATETRANSFORM,
    SET,
    VIEW,
    USE,
    STOP,
)
from probo.components.tag_functions import (
    a,
    abbr,
    address,
    article,
    aside,
    audio,
    b,
    bdi,
    bdo,
    blockquote,
    body,
    button,
    canvas,
    caption,
    cite,
    code,
    colgroup,
    data,
    datalist,
    dd,
    Del,
    details,
    dfn,
    dialog,
    div,
    dl,
    dt,
    em,
    fieldset,
    figcaption,
    figure,
    footer,
    form,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    head,
    header,
    hgroup,
    html,
    i,
    iframe,
    ins,
    kbd,
    label,
    legend,
    li,
    main,
    math,
    Map,
    mark,
    menu,
    meter,
    nav,
    noscript,
    Object,
    ol,
    optgroup,
    option,
    output,
    p,
    portal,
    picture,
    pre,
    progress,
    q,
    rp,
    rt,
    ruby,
    s,
    samp,
    script,
    search,
    section,
    select,
    slot,
    small,
    span,
    strong,
    style,
    sub,
    summary,
    sup,
    table,
    tbody,
    td,
    template,
    textarea,
    tfoot,
    th,
    thead,
    time,
    title,
    tr,
    u,
    ul,
    var,
    video,
    # self closing functions
    doctype,
    area,
    base,
    br,
    col,
    embed,
    hr,
    img,
    Input,
    link,
    meta,
    param,
    source,
    track,
    wbr,
    # svg elements
    g,
    defs,
    text,
    tspan,
    svg,
    symbol,
    marker,
    pattern,
    mask,
    clippath,
    lineargradient,
    radialgradient,
    Filter,
    fecomponenttransfer,
    fediffuselighting,
    femerge,
    fespecularlighting,
    animatemotion,
    forienobject,
    path,
    circle,
    rect,
    line,
    polyline,
    polygon,
    ellipse,
    image,
    feBlend,
    feColorMatrix,
    feComposite,
    feConvolveMatrix,
    feDisplacementMap,
    feDropShadow,
    feFlood,
    feFuncA,
    feFuncB,
    feFuncG,
    feFuncR,
    feGaussianBlur,
    feImage,
    feMergeNode,
    feMorphology,
    feOffset,
    fePointLight,
    feSpotLight,
    feTile,
    feTurbulence,
    animate,
    animateTransform,
    Set,
    view,
    use,
    stop,

)

from probo.styles import (
    element_style,
    CssRule,
    CssSelector,
    Css_Style,
    Css_Comment,
    BS5ElementStyle,
    Box_Model,
    Make_Important,
    BS5Element,
)

__all__ = [
    "A",
    "ABBR",
    "ADDRESS",
    "ARTICLE",
    "ASIDE",
    "AUDIO",
    "B",
    "BDI",
    "BDO",
    "BLOCKQUOTE",
    "BODY",
    "BUTTON",
    "CANVAS",
    "CAPTION",
    "CITE",
    "CODE",
    "COLGROUP",
    "DATA",
    "DATALIST",
    "DD",
    "DEL",
    "DETAILS",
    "DFN",
    "DIALOG",
    "DIV",
    "DL",
    "DT",
    "EM",
    "FIELDSET",
    "FIGCAPTION",
    "FIGURE",
    "FOOTER",
    "FORM",
    "H1",
    "H2",
    "H3",
    "H4",
    "H5",
    "H6",
    "HEAD",
    "HEADER",
    "HGROUP",
    "HTML",
    "I",
    "IFRAME",
    "INS",
    "KBD",
    "LABEL",
    "LEGEND",
    "LI",
    "MAIN",
    "MATH",
    "MAP",
    "MARK",
    "MENU",
    "METER",
    "NAV",
    "NOSCRIPT",
    "OBJECT",
    "OL",
    "OPTGROUP",
    "OPTION",
    "OUTPUT",
    "P",
    "PORTAL",
    "PICTURE",
    "PRE",
    "PROGRESS",
    "Q",
    "RP",
    "RT",
    "RUBY",
    "S",
    "SAMP",
    "SCRIPT",
    "SEARCH",
    "SECTION",
    "SELECT",
    "SLOT",
    "SMALL",
    "SPAN",
    "STRONG",
    "STYLE",
    "SUB",
    "SUMMARY",
    "SUP",
    "TABLE",
    "TBODY",
    "TD",
    "TEMPLATE",
    "TEXTAREA",
    "TFOOT",
    "TH",
    "THEAD",
    "TIME",
    "TITLE",
    "TR",
    "U",
    "UL",
    "VAR",
    "VIDEO",
    #SELF CLOSING
    "DOCTYPE",
    "AREA",
    "BASE",
    "BR",
    "COL",
    "EMBED",
    "HR",
    "IMG",
    "INPUT",
    "LINK",
    "META",
    "PARAM",
    "SOURCE",
    "TRACK",
    "WBR",
# svg elements
    'G',
    'DEFS',
    'TEXT',
    'TSPAN',
    'SVG',
    'SYMBOL',
    'MARKER',
    'PATTERN',
    'MASK',
    'CLIPPATH',
    'LINEARGRADIENT',
    'RADIALGRADIENT',
    'FILTER',
    'FECOMPONENTTRANSFER',
    'FEDIFFUSELIGHTING',
    'FEMERGE',
    'FESPECULARLIGHTING',
    'ANIMATEMOTION',
    'FOREIGNOBJECT',
    'PATH',
    'CIRCLE',
    'RECT',
    'LINE',
    'POLYLINE',
    'POLYGON',
    'ELLIPSE',
    'IMAGE',
    'FEBLEND',
    'FECOLORMATRIX',
    'FECOMPOSITE',
    'FECONVOLVEMATRIX',
    'FEDISPLACEMENTMAP',
    'FEDROPSHADOW',
    'FEFLOOD',
    'FEFUNCA',
    'FEFUNCB',
    'FEFUNCG',
    'FEFUNCR',
    'FEGAUSSIANBLUR',
    'FEIMAGE',
    'FEMERGENODE',
    'FEMORPHOLOGY',
    'FEOFFSET',
    'FEPOINTLIGHT',
    'FESPOTLIGHT',
    'FETILE',
    'FETURBULENCE',
    'ANIMATE',
    'ANIMATETRANSFORM',
    'SET',
    'VIEW',
    'USE',
    'STOP',
       
    "a",
    "abbr",
    "address",
    "article",
    "aside",
    "audio",
    "b",
    "bdi",
    "bdo",
    "blockquote",
    "body",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "colgroup",
    "data",
    "datalist",
    "dd",
    "Del",
    "details",
    "dfn",
    "dialog",
    "div",
    "dl",
    "dt",
    "em",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "head",
    "header",
    "hgroup",
    "html",
    "i",
    "iframe",
    "ins",
    "kbd",
    "label",
    "legend",
    "li",
    "main",
    "math",
    "Map",
    "mark",
    "menu",
    "meter",
    "nav",
    "noscript",
    "Object",
    "ol",
    "optgroup",
    "option",
    "output",
    "p",
    "portal",
    "picture",
    "pre",
    "progress",
    "q",
    "rp",
    "rt",
    "ruby",
    "s",
    "samp",
    "script",
    "search",
    "section",
    "select",
    "slot",
    "small",
    "span",
    "strong",
    "style",
    "sub",
    "summary",
    "sup",
    "svg",
    "table",
    "tbody",
    "td",
    "template",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time",
    "title",
    "tr",
    "u",
    "ul",
    "var",
    "video",
    #self closing
    "doctype",
    "area",
    "base",
    "br",
    "col",
    "embed",
    "hr",
    "img",
    "Input",
    "link",
    "meta",
    "param",
    "source",
    "track",
    "wbr",
    # svg elements
    'g',
    'defs',
    'text',
    'tspan',
    'svg',
    'symbol',
    'marker',
    'pattern',
    'mask',
    'clippath',
    'lineargradient',
    'radialgradient',
    'Filter',
    'fecomponenttransfer',
    'fediffuselighting',
    'femerge',
    'fespecularlighting',
    'animatemotion',
    'forienobject',
    'path',
    'circle',
    'rect',
    'line',
    'polyline',
    'polygon',
    'ellipse',
    'image',
    'feBlend',
    'feColorMatrix',
    'feComposite',
    'feConvolveMatrix',
    'feDisplacementMap',
    'feDropShadow',
    'feFlood',
    'feFuncA',
    'feFuncB',
    'feFuncG',
    'feFuncR',
    'feGaussianBlur',
    'feImage',
    'feMergeNode',
    'feMorphology',
    'feOffset',
    'fePointLight',
    'feSpotLight',
    'feTile',
    'feTurbulence',
    'animate',
    'animateTransform',
    'Set',
    'view',
    'use',
    'stop',

    "element_style",
    "CssRule",
    "CssSelector",
    "Css_Style",
    "Css_Comment",
    "BS5ElementStyle",
    "Box_Model",
    "Make_Important",
    "BS5Element",
]
