from probo.components.tag_functions.block_tags import (
    a,
    abbr,
    address,
    article,
    aside,
    audio,
    b,
    bdi,
    bdo,
    blockquote,
    body,
    button,
    canvas,
    caption,
    cite,
    code,
    colgroup,
    data,
    datalist,
    dd,
    Del,
    details,
    dfn,
    dialog,
    div,
    dl,
    dt,
    em,
    fieldset,
    figcaption,
    figure,
    footer,
    form,
    h1,
    h2,
    h3,
    h4,
    h5,
    h6,
    head,
    header,
    hgroup,
    html,
    i,
    iframe,
    ins,
    kbd,
    label,
    legend,
    li,
    main,
    math,
    Map,
    mark,
    menu,
    meter,
    nav,
    noscript,
    Object,
    ol,
    optgroup,
    option,
    output,
    p,
    portal,
    picture,
    pre,
    progress,
    q,
    rp,
    rt,
    ruby,
    s,
    samp,
    script,
    search,
    section,
    select,
    slot,
    small,
    span,
    strong,
    style,
    sub,
    summary,
    sup,
    table,
    tbody,
    td,
    template,
    textarea,
    tfoot,
    th,
    thead,
    time,
    title,
    tr,
    u,
    ul,
    var,
    video,
)
from probo.components.tag_functions.self_closing import (
    doctype,
    area,
    base,
    br,
    col,
    embed,
    hr,
    img,
    Input,
    link,
    meta,
    param,
    source,
    track,
    wbr,
)
from probo.components.tag_functions.svg_tags import (
    g,
    defs,
    text,
    tspan,
    svg,
    symbol,
    marker,
    pattern,
    mask,
    clippath,
    lineargradient,
    radialgradient,
    Filter,
    fecomponenttransfer,
    fediffuselighting,
    femerge,
    fespecularlighting,
    animatemotion,
    forienobject,
    path,
    circle,
    rect,
    line,
    polyline,
    polygon,
    ellipse,
    image,
    feBlend,
    feColorMatrix,
    feComposite,
    feConvolveMatrix,
    feDisplacementMap,
    feDropShadow,
    feFlood,
    feFuncA,
    feFuncB,
    feFuncG,
    feFuncR,
    feGaussianBlur,
    feImage,
    feMergeNode,
    feMorphology,
    feOffset,
    fePointLight,
    feSpotLight,
    feTile,
    feTurbulence,
    animate,
    animateTransform,
    Set,
    view,
    use,
    stop,
)

__all__ = [
    # block functions
    "a",
    "abbr",
    "address",
    "article",
    "aside",
    "audio",
    "b",
    "bdi",
    "bdo",
    "blockquote",
    "body",
    "button",
    "canvas",
    "caption",
    "cite",
    "code",
    "colgroup",
    "data",
    "datalist",
    "dd",
    "Del",
    "details",
    "dfn",
    "dialog",
    "div",
    "dl",
    "dt",
    "em",
    "fieldset",
    "figcaption",
    "figure",
    "footer",
    "form",
    "h1",
    "h2",
    "h3",
    "h4",
    "h5",
    "h6",
    "head",
    "header",
    "hgroup",
    "html",
    "i",
    "iframe",
    "ins",
    "kbd",
    "label",
    "legend",
    "li",
    "main",
    "math",
    "Map",
    "mark",
    "menu",
    "meter",
    "nav",
    "noscript",
    "Object",
    "ol",
    "optgroup",
    "option",
    "output",
    "p",
    "portal",
    "picture",
    "pre",
    "progress",
    "q",
    "rp",
    "rt",
    "ruby",
    "s",
    "samp",
    "script",
    "search",
    "section",
    "select",
    "slot",
    "small",
    "span",
    "strong",
    "style",
    "sub",
    "summary",
    "sup",
    "table",
    "tbody",
    "td",
    "template",
    "textarea",
    "tfoot",
    "th",
    "thead",
    "time",
    "title",
    "tr",
    "u",
    "ul",
    "var",
    "video",
    # self closing functions
    "doctype",
    "area",
    "base",
    "br",
    "col",
    "embed",
    "hr",
    "img",
    "Input",
    "link",
    "meta",
    "param",
    "source",
    "track",
    "wbr",
    # svg elements
    'g',
    'defs',
    'text',
    'tspan',
    'svg',
    'symbol',
    'marker',
    'pattern',
    'mask',
    'clippath',
    'lineargradient',
    'radialgradient',
    'Filter',
    'fecomponenttransfer',
    'fediffuselighting',
    'femerge',
    'fespecularlighting',
    'animatemotion',
    'forienobject',
    'path',
    'circle',
    'rect',
    'line',
    'polyline',
    'polygon',
    'ellipse',
    'image',
    'feBlend',
    'feColorMatrix',
    'feComposite',
    'feConvolveMatrix',
    'feDisplacementMap',
    'feDropShadow',
    'feFlood',
    'feFuncA',
    'feFuncB',
    'feFuncG',
    'feFuncR',
    'feGaussianBlur',
    'feImage',
    'feMergeNode',
    'feMorphology',
    'feOffset',
    'fePointLight',
    'feSpotLight',
    'feTile',
    'feTurbulence',
    'animate',
    'animateTransform',
    'Set',
    'view',
    'use',
    'stop',
]
